@@ -4,7 +4,6 @@ set -e
 set -x
 
 echo "ENV=${ENV}"
-echo "REDIS_URL-${REDIS_URL}"
 
 export PYTHONPATH=.
-pytest --cov=authx --cov=tests
\ No newline at end of file
+pytest --cov=authx --cov-report=xml
